==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Classification/group__PkgClassificationLabel.js <==
var group__PkgClassificationLabel =
[
    [ "Label", "classCGAL_1_1Classification_1_1Label.html", [
      [ "color", "classCGAL_1_1Classification_1_1Label.html#a9c3f1dfa634752bf11eb0e9f494a66be", null ],
      [ "index", "classCGAL_1_1Classification_1_1Label.html#aacf5cddbe4533e4a761d466689d25154", null ],
      [ "name", "classCGAL_1_1Classification_1_1Label.html#ac7cd2d4fd6f3f2e6d190f3577478de09", null ],
      [ "set_color", "classCGAL_1_1Classification_1_1Label.html#aca3c024d76781cd5b1b6e5fd23157cb3", null ],
      [ "set_name", "classCGAL_1_1Classification_1_1Label.html#a602eeadb59e609a261057d57b2e4a155", null ],
      [ "set_standard_index", "classCGAL_1_1Classification_1_1Label.html#a0720b3c4e15b1af3f8435e4de195bfce", null ],
      [ "standard_index", "classCGAL_1_1Classification_1_1Label.html#a10859dd652c0d609ba228419a53f182e", null ]
    ] ],
    [ "Label_handle", "classCGAL_1_1Classification_1_1Label__handle.html", null ],
    [ "Label_set", "classCGAL_1_1Classification_1_1Label__set.html", [
      [ "const_iterator", "classCGAL_1_1Classification_1_1Label__set.html#a43b4d644d5b8369333782482fe31c70a", null ],
      [ "iterator", "classCGAL_1_1Classification_1_1Label__set.html#a02e0bbc313467b0a1a154cf9d5a6fded", null ],
      [ "Label_set", "classCGAL_1_1Classification_1_1Label__set.html#a9e73846e2e4e57208b7193682387c904", null ],
      [ "Label_set", "classCGAL_1_1Classification_1_1Label__set.html#af993cbf5da1379126c7901a226fbb526", null ],
      [ "add", "classCGAL_1_1Classification_1_1Label__set.html#afaa0d2e86c20b0c7ef19ce5e3f6b1104", null ],
      [ "add", "classCGAL_1_1Classification_1_1Label__set.html#afdf6883410267aba7fcbb146d10e98f8", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Label__set.html#a303876a713af05889ff6488de9817e2e", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Label__set.html#ac4c7add32e8306d02d361d662b062999", null ],
      [ "clear", "classCGAL_1_1Classification_1_1Label__set.html#a172acf399f2b5e3ca8fc5521932c0d41", null ],
      [ "end", "classCGAL_1_1Classification_1_1Label__set.html#a7d0c086432882775f5ab997e36ef4001", null ],
      [ "end", "classCGAL_1_1Classification_1_1Label__set.html#af616d8bd5ea326fc5d7130326aaf1407", null ],
      [ "is_valid_ground_truth", "classCGAL_1_1Classification_1_1Label__set.html#adeb3b046f640c091b1f123e982386e43", null ],
      [ "operator[]", "classCGAL_1_1Classification_1_1Label__set.html#a49d57a3e6886297116a3b378ef15ad58", null ],
      [ "remove", "classCGAL_1_1Classification_1_1Label__set.html#a3e237793f3bd289b130ff39039b89443", null ],
      [ "size", "classCGAL_1_1Classification_1_1Label__set.html#a10a122580143de44adc9758e2eb88046", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Classification/group__PkgClassificationLabel.js <==
var group__PkgClassificationLabel =
[
    [ "CGAL::Classification::Label", "classCGAL_1_1Classification_1_1Label.html", [
      [ "color", "classCGAL_1_1Classification_1_1Label.html#a38b3fb81b094493db6187bf47dc527cc", null ],
      [ "index", "classCGAL_1_1Classification_1_1Label.html#aacf5cddbe4533e4a761d466689d25154", null ],
      [ "name", "classCGAL_1_1Classification_1_1Label.html#a0710ddd35200062e9a40c3f485e5c4df", null ],
      [ "set_color", "classCGAL_1_1Classification_1_1Label.html#aca3c024d76781cd5b1b6e5fd23157cb3", null ],
      [ "set_name", "classCGAL_1_1Classification_1_1Label.html#a602eeadb59e609a261057d57b2e4a155", null ],
      [ "set_standard_index", "classCGAL_1_1Classification_1_1Label.html#a0720b3c4e15b1af3f8435e4de195bfce", null ],
      [ "standard_index", "classCGAL_1_1Classification_1_1Label.html#a10859dd652c0d609ba228419a53f182e", null ]
    ] ],
    [ "CGAL::Classification::Label_handle", "classCGAL_1_1Classification_1_1Label__handle.html", null ],
    [ "CGAL::Classification::Label_set", "classCGAL_1_1Classification_1_1Label__set.html", [
      [ "const_iterator", "classCGAL_1_1Classification_1_1Label__set.html#a43b4d644d5b8369333782482fe31c70a", null ],
      [ "iterator", "classCGAL_1_1Classification_1_1Label__set.html#a02e0bbc313467b0a1a154cf9d5a6fded", null ],
      [ "Label_set", "classCGAL_1_1Classification_1_1Label__set.html#a9e73846e2e4e57208b7193682387c904", null ],
      [ "Label_set", "classCGAL_1_1Classification_1_1Label__set.html#ab86e54d75a3132ac90842bb6b71fd710", null ],
      [ "add", "classCGAL_1_1Classification_1_1Label__set.html#afdf6883410267aba7fcbb146d10e98f8", null ],
      [ "add", "classCGAL_1_1Classification_1_1Label__set.html#afaa0d2e86c20b0c7ef19ce5e3f6b1104", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Label__set.html#ac4c7add32e8306d02d361d662b062999", null ],
      [ "begin", "classCGAL_1_1Classification_1_1Label__set.html#a303876a713af05889ff6488de9817e2e", null ],
      [ "clear", "classCGAL_1_1Classification_1_1Label__set.html#a172acf399f2b5e3ca8fc5521932c0d41", null ],
      [ "end", "classCGAL_1_1Classification_1_1Label__set.html#af616d8bd5ea326fc5d7130326aaf1407", null ],
      [ "end", "classCGAL_1_1Classification_1_1Label__set.html#a7d0c086432882775f5ab997e36ef4001", null ],
      [ "is_valid_ground_truth", "classCGAL_1_1Classification_1_1Label__set.html#adeb3b046f640c091b1f123e982386e43", null ],
      [ "operator[]", "classCGAL_1_1Classification_1_1Label__set.html#a49d57a3e6886297116a3b378ef15ad58", null ],
      [ "remove", "classCGAL_1_1Classification_1_1Label__set.html#a3e237793f3bd289b130ff39039b89443", null ],
      [ "size", "classCGAL_1_1Classification_1_1Label__set.html#a10a122580143de44adc9758e2eb88046", null ]
    ] ]
];
